==> qt6-qtdeclarative-6.3.1.tgz: include/X11/qt6/QtQuick/6.3.1/QtQuick/private/qquickpalettecolorprovider_p.h <==
/****************************************************************************
**
** Copyright (C) 2020 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtQuick module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef QQUICKPALETTECOLORPROVIDER_P_H
#define QQUICKPALETTECOLORPROVIDER_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <QtGui/QPalette>

#include <QtQuick/qtquickglobal.h>

#include <QtQuick/private/qtquickglobal_p.h>
#include <private/qlazilyallocated_p.h>

QT_BEGIN_NAMESPACE

class QQuickAbstractPaletteProvider;

class Q_QUICK_PRIVATE_EXPORT QQuickPaletteColorProvider
    : public std::enable_shared_from_this<QQuickPaletteColorProvider>
{
public:
    QQuickPaletteColorProvider();

    const QColor &color(QPalette::ColorGroup group, QPalette::ColorRole role) const;
    bool setColor(QPalette::ColorGroup group, QPalette::ColorRole role, QColor color);
    bool resetColor(QPalette::ColorGroup group, QPalette::ColorRole role);

    bool fromQPalette(QPalette p);
    QPalette palette() const;

    const QQuickAbstractPaletteProvider *paletteProvider() const;
    void setPaletteProvider(const QQuickAbstractPaletteProvider *paletteProvider);

    bool copyColorGroup(QPalette::ColorGroup cg, const QQuickPaletteColorProvider &p);

    bool reset();

    bool inheritPalette(const QPalette &p);

private:
    QPalette m_resolvedPalette;
    QLazilyAllocated<QPalette> m_requestedPalette;

    using Deleter = std::function<void(const QQuickAbstractPaletteProvider*)>;
    using ProviderPtr = std::unique_ptr<const QQuickAbstractPaletteProvider, Deleter>;
    ProviderPtr m_paletteProvider;
};

QT_END_NAMESPACE

#endif // QQUICKPALETTECOLORPROVIDER_P_H

==> qt6-qtdeclarative-6.7.3p0.tgz: include/X11/qt6/QtQuick/6.7.3/QtQuick/private/qquickpalettecolorprovider_p.h <==
// Copyright (C) 2020 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef QQUICKPALETTECOLORPROVIDER_P_H
#define QQUICKPALETTECOLORPROVIDER_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <QtGui/QPalette>

#include <QtQuick/qtquickglobal.h>

#include <QtQuick/private/qtquickglobal_p.h>
#include <private/qlazilyallocated_p.h>

QT_BEGIN_NAMESPACE

class QQuickAbstractPaletteProvider;

class Q_QUICK_PRIVATE_EXPORT QQuickPaletteColorProvider
    : public std::enable_shared_from_this<QQuickPaletteColorProvider>
{
public:
    QQuickPaletteColorProvider();

    const QColor &color(QPalette::ColorGroup group, QPalette::ColorRole role) const;
    bool setColor(QPalette::ColorGroup group, QPalette::ColorRole role, QColor color);
    bool resetColor(QPalette::ColorGroup group, QPalette::ColorRole role);
    bool resetColor(QPalette::ColorGroup group);

    bool fromQPalette(QPalette p);
    QPalette palette() const;

    const QQuickAbstractPaletteProvider *paletteProvider() const;
    void setPaletteProvider(const QQuickAbstractPaletteProvider *paletteProvider);

    bool copyColorGroup(QPalette::ColorGroup cg, const QQuickPaletteColorProvider &p);

    bool reset();

    bool inheritPalette(const QPalette &palette);

private:
    bool doInheritPalette(const QPalette &palette);
    bool updateInheritedPalette();
    void ensureRequestedPalette();

    QPalette m_resolvedPalette;
    QLazilyAllocated<QPalette> m_requestedPalette;
    QLazilyAllocated<QPalette> m_lastInheritedPalette;

    using Deleter = std::function<void(const QQuickAbstractPaletteProvider*)>;
    using ProviderPtr = std::unique_ptr<const QQuickAbstractPaletteProvider, Deleter>;
    ProviderPtr m_paletteProvider;
};

QT_END_NAMESPACE

#endif // QQUICKPALETTECOLORPROVIDER_P_H
